FfiCell

Struct FfiCell 

pub struct FfiCell<T: Sync> { /* private fields */ }

Implementations

Source

impl<T: Sync> FfiCell<T>

pub const fn new() -> Self

pub fn run<R>(&self, object: &mut T, f: impl FnOnce() -> R) -> R

pub fn try_run<R>( &self, object: &mut T, f: impl FnOnce() -> R, ) -> Result<R, Error>

pub unsafe fn lend(&self, ptr: &mut T)

Safety

The object pointed to in the params cannot be referenced until reclaim is called without panicking or try_reclaim is called and returns Ok.

pub unsafe fn try_lend(&self, ptr: &mut T) -> Result<(), LendError>

Safety

The object pointed to in the params cannot be referenced until reclaim is called without panicking or try_reclaim is called and returns Ok.

pub fn borrow(&self) -> impl DerefMut<Target = T>

pub fn try_borrow(&self) -> Result<impl DerefMut<Target = T>, BorrowError>

pub fn reclaim(&self)

pub fn try_reclaim(&self) -> Result<(), ReclaimError>